@@ -31,13 +31,15 @@
 
 #include "wave_locale.h"
 
+#define VZT_VCD_WRITE_BUF_SIZ (2 * 1024 * 1024)
+
 static int flat_earth = 0;
 static int vectorize = 0;
 static int notruncate = 0;
+static FILE *fv = NULL;
 
 extern void free_hier(void);
-extern char *output_hier(char *name);
-
+extern char *fv_output_hier(FILE *fv, char *name);
 
 /*
  * generate a vcd identifier for a given facindx
@@ -125,7 +127,7 @@ struct vzt_rd_geometry *g = vzt_rd_get_fac_geometry(*lt, *pnt_facidx);
 if(vcd_prevtime != *pnt_time)
 	{
 	vcd_prevtime = *pnt_time;
-	printf("#"VZT_RD_LLD"\n", *pnt_time);
+	fprintf(fv, "#"VZT_RD_LLD"\n", *pnt_time);
 	}
 
 if(!(*pnt_value)[0])
@@ -133,7 +135,7 @@ if(!(*pnt_value)[0])
 	if(!vcd_blackout)
 		{
 		vcd_blackout = 1;
-		printf("$dumpoff\n");
+		fprintf(fv, "$dumpoff\n");
 		}
 
 	return;
@@ -143,28 +145,28 @@ if(!(*pnt_value)[0])
 	if(vcd_blackout)
 		{
 		vcd_blackout = 0;
-		printf("$dumpon\n");
+		fprintf(fv, "$dumpon\n");
 		}	
 	}
 
 if(g->flags & VZT_RD_SYM_F_DOUBLE)
 	{
-        printf("r%s %s\n", *pnt_value, vcdid(*pnt_facidx));
+        fprintf(fv, "r%s %s\n", *pnt_value, vcdid(*pnt_facidx));
         }
 else
 if(g->flags & VZT_RD_SYM_F_STRING)
 	{
-        printf("s%s %s\n", *pnt_value, vcdid(*pnt_facidx));
+        fprintf(fv, "s%s %s\n", *pnt_value, vcdid(*pnt_facidx));
         }
 else
 	{
         if(g->len==1)
         	{
-                printf("%c%s\n", (*pnt_value)[0], vcdid(*pnt_facidx));
+                fprintf(fv, "%c%s\n", (*pnt_value)[0], vcdid(*pnt_facidx));
                 }
                 else
                 {                        
-                printf("b%s %s\n", vcd_truncate_bitvec(*pnt_value), vcdid(*pnt_facidx));
+                fprintf(fv, "b%s %s\n", vcd_truncate_bitvec(*pnt_value), vcdid(*pnt_facidx));
                 }
 	}                               
 }
@@ -220,16 +222,16 @@ if(lt)
                 }
 
         time(&walltime);
-        printf("$date\n");
-        printf("\t%s",asctime(localtime(&walltime)));
-        printf("$end\n");
-        printf("$version\n\tvzt2vcd\n$end\n");
-	printf("$timescale %d%c%c $end\n", time_scale, time_dimension, !scale ? ' ' : 's');
+        fprintf(fv, "$date\n");
+        fprintf(fv, "\t%s",asctime(localtime(&walltime)));
+        fprintf(fv, "$end\n");
+        fprintf(fv, "$version\n\tvzt2vcd\n$end\n");
+	fprintf(fv, "$timescale %d%c%c $end\n", time_scale, time_dimension, !scale ? ' ' : 's');
 
 	timezero = vzt_rd_get_timezero(lt);
 	if(timezero)
 		{
-		printf("$timezero "VZT_RD_LLD" $end\n", timezero);
+		fprintf(fv, "$timezero "VZT_RD_LLD" $end\n", timezero);
 		}
 
 	for(i=0;i<numfacs;i++)
@@ -244,7 +246,7 @@ if(lt)
 
 		if(!flat_earth)
 			{
-			netname = output_hier(vzt_rd_get_facname(lt, i));
+			netname = fv_output_hier(fv, vzt_rd_get_facname(lt, i));
 			}
 			else
 			{
@@ -253,12 +255,12 @@ if(lt)
 
                 if(g->flags & VZT_RD_SYM_F_DOUBLE)
                 	{
-                        printf("$var real 1 %s %s $end\n", vcdid(newindx), netname);
+                        fprintf(fv, "$var real 1 %s %s $end\n", vcdid(newindx), netname);
                         }
                 else
                 if(g->flags & VZT_RD_SYM_F_STRING)
                        {
-                       printf("$var real 1 %s %s $end\n", vcdid(newindx), netname);
+                       fprintf(fv, "$var real 1 %s %s $end\n", vcdid(newindx), netname);
                        }
                 else
 			
@@ -267,22 +269,22 @@ if(lt)
                        		{
                                 if(g->msb!=-1)
                                 	{
-                                        printf("$var wire 1 %s %s ["VZT_RD_LD"] $end\n", vcdid(newindx), netname, g->msb);
+                                        fprintf(fv, "$var wire 1 %s %s ["VZT_RD_LD"] $end\n", vcdid(newindx), netname, g->msb);
                                         }
                                         else
                                         {
-                                        printf("$var wire 1 %s %s $end\n", vcdid(newindx), netname);
+                                        fprintf(fv, "$var wire 1 %s %s $end\n", vcdid(newindx), netname);
                                         }  
 				}
                                 else
                                 {
 				if(!(g->flags & VZT_RD_SYM_F_INTEGER))
 					{
-	                                if(g->len) printf("$var wire "VZT_RD_LD" %s %s ["VZT_RD_LD":"VZT_RD_LD"] $end\n", g->len, vcdid(newindx), netname, g->msb, g->lsb);
+	                                if(g->len) fprintf(fv, "$var wire "VZT_RD_LD" %s %s ["VZT_RD_LD":"VZT_RD_LD"] $end\n", g->len, vcdid(newindx), netname, g->msb, g->lsb);
 					}
 					else
 					{
-	                                printf("$var integer "VZT_RD_LD" %s %s $end\n", g->len, vcdid(newindx), netname);
+	                                fprintf(fv, "$var integer "VZT_RD_LD" %s %s $end\n", g->len, vcdid(newindx), netname);
 					}
                                 }
                         }
@@ -290,12 +292,12 @@ if(lt)
 
 	if(!flat_earth)
 		{
-		output_hier(""); /* flush any remaining hierarchy if not back to toplevel */
+		fv_output_hier(fv, ""); /* flush any remaining hierarchy if not back to toplevel */
 		free_hier();
 		}
 
-	printf("$enddefinitions $end\n");
-	printf("$dumpvars\n");
+	fprintf(fv, "$enddefinitions $end\n");
+	fprintf(fv, "$dumpvars\n");
 
 	vcd_prevtime = vzt_rd_get_start_time(lt)-1;
 
@@ -303,7 +305,7 @@ if(lt)
 
 	if(vcd_prevtime!=vzt_rd_get_end_time(lt))
 		{
-		printf("#"VZT_RD_LLD"\n", vzt_rd_get_end_time(lt));
+		fprintf(fv, "#"VZT_RD_LLD"\n", vzt_rd_get_end_time(lt));
 		}
 
 	vzt_rd_close(lt);
@@ -325,22 +327,23 @@ void print_help(char *nam)
 printf(
 "Usage: %s [OPTION]... [VZTFILE]\n\n"
 "  -v, --vztname=FILE         specify VZT input filename\n"
+"  -o, --output=FILE          specify output filename\n"
 "  -f, --flatearth            emit flattened hierarchies\n"
 "  -c, --coalesce             coalesce bitblasted vectors\n"
 "  -n, --notruncate           do not shorten bitvectors\n"
 "  -h, --help                 display this help then exit\n\n"
-"VCD is emitted to stdout.\n\n"
+"VCD is emitted to stdout if output filename is unspecified.\n\n"
 "Report bugs to <"PACKAGE_BUGREPORT">.\n",nam);
 #else
 printf(
 "Usage: %s [OPTION]... [VZTFILE]\n\n"
 "  -v                         specify VZT input filename\n"
+"  -o                         specify output filename\n"
 "  -f                         emit flattened hierarchies\n"
 "  -c                         coalesce bitblasted vectors\n"
 "  -n                         do not shorten bitvectors\n"
 "  -h                         display this help then exit\n\n"
-
-"VCD is emitted to stdout.\n\n"
+"VCD is emitted to stdout if output filename is unspecified.\n\n"
 "Report bugs to <"PACKAGE_BUGREPORT">.\n",nam);
 #endif
 
@@ -352,6 +355,8 @@ int main(int argc, char **argv)
 {
 char opt_errors_encountered=0;
 char *lxname=NULL;
+char *outname=NULL;
+char *fvbuf=NULL;
 int c;
 int rc;
 
@@ -365,6 +370,7 @@ while (1)
         static struct option long_options[] =
                 {
 		{"vztname", 1, 0, 'v'},
+		{"output", 1, 0, 'o'},		
 		{"coalesce", 0, 0, 'c'},
 		{"flatearth", 0, 0, 'f'},
 		{"notruncate", 0, 0, 'n'},
@@ -372,9 +378,9 @@ while (1)
                 {0, 0, 0, 0}  
                 };
                 
-        c = getopt_long (argc, argv, "v:cfnh", long_options, &option_index);
+        c = getopt_long (argc, argv, "v:o:cfnh", long_options, &option_index);
 #else
-        c = getopt      (argc, argv, "v:cfnh");
+        c = getopt      (argc, argv, "v:o:cfnh");
 #endif
                         
         if (c == -1) break;     /* no more args */
@@ -387,6 +393,12 @@ while (1)
                         strcpy(lxname, optarg);
 			break;
 
+               case 'o':
+                        if(outname) free(outname);
+                        outname = malloc(strlen(optarg)+1);
+                        strcpy(outname, optarg);
+                        break;
+
 		case 'c': vectorize=1;
 			break;
 
@@ -432,7 +444,32 @@ if(!lxname)
         print_help(argv[0]);
         }
 
+if(outname)
+       	{
+       	fv = fopen(outname, "wb");
+        if(!fv)
+                {
+                fprintf(stderr, "Could not open '%s', exiting.\n", outname);
+                perror("Why");
+                exit(255);
+               	}
+        fvbuf = malloc(VZT_VCD_WRITE_BUF_SIZ);
+        setvbuf(fv, fvbuf, _IOFBF, VZT_VCD_WRITE_BUF_SIZ);
+        }
+        else
+	{
+        fv = stdout;
+        }
+
 rc=process_vzt(lxname);
+
+if(outname)
+        {
+        free(outname);
+        fclose(fv);
+        }
+
+free(fvbuf);
 free(lxname);
 
 return(rc);
